@@ -1,7 +1,5 @@
 
 /*
- * $Id$
- *
  * DEBUG: none          LRU Removal Policy
  * AUTHOR: Henrik Nordstrom
  *
@@ -33,7 +31,7 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "Store.h"
 #include "MemObject.h"
 #include "SquidTime.h"
@@ -244,7 +242,7 @@ try_again:
 
     if (entry->locked()) {
         /* Shit, it is locked. we can't return this one */
-        walker->locked++;
+        ++ walker->locked;
         dlinkAddTail(entry, &lru_node->node, &lru->list);
         goto try_again;
     }
